pub type PluginID = &'static str;Expand description
Plugin identifier type.
Every plugin must have a unique identifier. This type is used to identify plugins within the steckrs system. It’s implemented as a static string reference for efficiency and simplicity.
See also PluginIDOwned, which can be owned and provides serialization support, if you need
that.
Examples
let id: steckrs::PluginID = "hello_world_plugin";Trait Implementations
Sourceimpl From<&PluginIDOwned> for PluginID
impl From<&PluginIDOwned> for PluginID
Sourcefn from(value: &PluginIDOwned) -> Self
fn from(value: &PluginIDOwned) -> Self
Converts to this type from the input type.
Sourceimpl From<PluginIDOwned> for PluginID
impl From<PluginIDOwned> for PluginID
Sourcefn from(value: PluginIDOwned) -> Self
fn from(value: PluginIDOwned) -> Self
Converts to this type from the input type.